@@ -5,9 +5,8 @@
 # License, v. 2.0. If a copy of the MPL was not distributed with this
 # file, You can obtain one at http://mozilla.org/MPL/2.0/.
 
-from copy import deepcopy
-from sys import stdin, stdout, stderr
-from os.path import splitext
+from sys import stderr
+
 import os
 
 from .base import PipelineStep
