@@ -272,9 +272,12 @@ class TimestreamFile(object):
 
     # TODO: work out where this should go. be careful, as setting here should sync to
     # disc perhaps?
-    # @content.setter
-    # def _set_content(self, content):
-    #    self._content = content
+    # gdunstone: I think this should be a reference to the un-decoded image data rather
+    # than sync to disk. TimeStreamFile should be storage backend agnostic, but provide
+    # an interface to sync to disk.
+    @content.setter
+    def content(self, content):
+        self._content = content
 
     @classmethod
     def from_path(cls, path, instant=None):
